# Copyright 2009 Simon Schampijer
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""HelloWorld Activity: A case study for developing an activity."""

from gi.repository import Gtk
import logging

from gettext import gettext as _

from sugar3.activity import activity
from sugar3.graphics.toolbarbox import ToolbarBox
from sugar3.activity.widgets import ActivityButton, ActivityToolbarButton
from sugar3.activity.widgets import TitleEntry
from sugar3.activity.widgets import StopButton
from sugar3.activity.widgets import ShareButton
from sugar3.activity.widgets import DescriptionItem

from sugar3.graphics.colorbutton import ColorToolButton

class HelloWorldActivity(activity.Activity):
    """HelloWorldActivity class as specified in activity.info"""

    def __init__(self, handle):
        """Set up the HelloWorld activity."""
        activity.Activity.__init__(self, handle)

        # we do not have collaboration features
        # make the share option insensitive
        self.max_participants = 1

        # toolbar with the new toolbar redesign
        toolbar_box = ToolbarBox()

        activity_button = ActivityToolbarButton(self)
        toolbar_box.toolbar.insert(activity_button, 0)
        activity_button.show()

        title_entry = TitleEntry(self)
        toolbar_box.toolbar.insert(title_entry, -1)
        title_entry.show()

        color_button = ColorToolButton()
        toolbar_box.toolbar.insert(color_button, -1)
        color_button.show()

        description_item = DescriptionItem(self)
        toolbar_box.toolbar.insert(description_item, -1)
        description_item.show()

        share_button = ShareButton(self)
        toolbar_box.toolbar.insert(share_button, -1)
        share_button.show()
        
        separator = Gtk.SeparatorToolItem()
        separator.props.draw = False
        separator.set_expand(True)
        toolbar_box.toolbar.insert(separator, -1)
        separator.show()

        stop_button = StopButton(self)
        toolbar_box.toolbar.insert(stop_button, -1)
        stop_button.show()

        self.set_toolbar_box(toolbar_box)
        toolbar_box.show()

        scrolledwindow = Gtk.ScrolledWindow()
        scrolledwindow.set_hexpand(True)
        scrolledwindow.set_vexpand(True)

        self.textview = Gtk.TextView()
        self.textview.set_wrap_mode(Gtk.WrapMode.WORD)
        self.textbuffer = self.textview.get_buffer()

        self.textbuffer.set_text('Hi this is a test, selecting is a must!'
                                 'Let\'s try if we can do that in several lines as well.'
                                 'Try to select the following paragraph: \"Please select me\"'
                                 'and then we have done the first part of this test. \n\n\n\n'
                                 'Let\'s see how this goes.'
                                 '\n\n\n\n\n\n Here the text continues...\n\n\n\n'
                                 '\n\n and then again another paragraph to make this even bigger...'
                                 '\n\n\n\n\n\n Here the text continues...\n\n\n\n'
                                 'Hi this is a test, selecting is a must!'
                                 'Let\'s try if we can do that in several lines as well.'
                                 'Try to select the following paragraph: \"Please select me\"'
                                 'and then we have done the first part of this test. '
                                 '\n\n\n\n\n\n Here the text continues...'
                                 '\n\n and then again another paragraph to make this even bigger...'
                                 '\n\n\n\n\n\n Here the text continues...\n\n\n\n'
                                 'The move from Fedora 17 to Fedora 18 has some risks. However the'
                                 'new features do not seem particularly risky for us. '
                                 'The ARM builders are already doing a good job on Fedora 18.'
                                 'A lot of work is needed for the Sugar GTK3 and touch efforts. '
                                 'Alignment with the proposed Sugar-0.98 release cycle aims to '
                                 'maximize the development time available while also leaving '
                                 'time for stabilisation. However the Sugar cycle is aligned '
                                 'to a later point in this plan, meaning risk is improved: '
                                 'we have very little room for delay,'
                                 'and we can\'t slip on implementing major features or fixing major issues. \n\n\n\n'
                                 'Risk in general is mitigated by the possibility of delaying the whole \n\n\n\n'
                                 'release cycle if hardware production delays become known. '
                                 'Let\'s try if we can do that in several lines as well.'
                                 'Try to select the following paragraph: \"Please select me\"'
                                 'and then we have done the first part of this test. \n\n\n\n'
                                 'Let\'s see how this goes.'
                                 '\n\n\n\n\n\n Here the text continues...\n\n\n\n'
                                 '\n\n and then again another paragraph to make this even bigger...'
                                 '\n\n\n\n\n\n Here the text continues...\n\n\n\n'
                                 'Hi this is a test, selecting is a must!'
                                 'Let\'s try if we can do that in several lines as well.'
                                 'Try to select the following paragraph: \"Please select me\"'
                                 'and then we have done the first part of this test. '
                                 '\n\n\n\n\n\n Here the text continues...'
                                 '\n\n and then again another paragraph to make this even bigger...'
                                 '\n\n\n\n\n\n Here the text continues...\n\n\n\n'
                                 'The move from Fedora 17 to Fedora 18 has some risks. However the'
                                 'new features do not seem particularly risky for us. '
                                 'The ARM builders are already doing a good job on Fedora 18.'
                                 'A lot of work is needed for the Sugar GTK3 and touch efforts. '
                                 'Alignment with the proposed Sugar-0.98 release cycle aims to '
                                 'maximize the development time available while also leaving '
                                 'time for stabilisation. However the Sugar cycle is aligned '
                                 'to a later point in this plan, meaning risk is improved: '
                                 'we have very little room for delay,'
)
        scrolledwindow.add(self.textview)
        self.textview.show()

        self.set_canvas(scrolledwindow)
        scrolledwindow.show()

